@@ -15,7 +15,7 @@ return @list_mounts_cache if (@list_mounts_cache);
 local(@rv, @p, $_, $i); $i = 0;
 
 # List normal filesystem mounts
-open(FSTAB, $config{fstab_file});
+open(FSTAB, "<".$config{fstab_file});
 while(<FSTAB>) {
 	chop; s/#.*$//g;
 	if (!/\S/) { next; }
@@ -27,7 +27,7 @@ while(<FSTAB>) {
 close(FSTAB);
 
 # List automount points
-open(AUTOTAB, $config{autofs_file});
+open(AUTOTAB, "<".$config{autofs_file});
 while(<AUTOTAB>) {
 	chop; s/#.*$//g;
 	if (!/\S/ || /^[+\-]/) { next; }
@@ -78,7 +78,7 @@ return $len;
 sub delete_mount
 {
 local(@fstab, $i, $line, $_);
-open(FSTAB, $config{fstab_file});
+open(FSTAB, "<".$config{fstab_file});
 @fstab = <FSTAB>;
 close(FSTAB);
 $i = 0;
@@ -93,7 +93,7 @@ foreach (@fstab) {
 	}
 &close_tempfile(FSTAB);
 
-open(AUTOTAB, $config{autofs_file});
+open(AUTOTAB, "<".$config{autofs_file});
 @autotab = <AUTOTAB>;
 close(AUTOTAB);
 &open_tempfile(AUTOTAB, "> $config{autofs_file}");
@@ -116,7 +116,7 @@ sub change_mount
 local(@fstab, @autotab, $i, $line, $fsck, $dir, $_);
 $i = 0;
 
-open(FSTAB, $config{fstab_file});
+open(FSTAB, "<".$config{fstab_file});
 @fstab = <FSTAB>;
 close(FSTAB);
 &open_tempfile(FSTAB, "> $config{fstab_file}");
@@ -136,7 +136,7 @@ foreach (@fstab) {
 	}
 &close_tempfile(FSTAB);
 
-open(AUTOTAB, $config{autofs_file});
+open(AUTOTAB, "<".$config{autofs_file});
 @autotab = <AUTOTAB>;
 close(AUTOTAB);
 &open_tempfile(AUTOTAB, "> $config{autofs_file}");
@@ -682,12 +682,12 @@ if ($_[0] eq "nfs") {
 
 	print "<tr> <td><b>$text{'solaris_proto'}</b></td>\n";
 	print "<td nowrap><select name=proto>\n";
-	printf "<option value=\"\" %s> $text{'default'}\n",
+	printf "<option value=\"\" %s>$text{'default'}</option>\n",
 		defined($options{"proto"}) ? "" : "selected";
 	&open_tempfile(NETCONFIG, "/etc/netconfig");
 	while(<NETCONFIG>) {
 		if (!/^([A-z0-9\_\-]+)\s/) { next; }
-		printf "<option value=\"$1\" %s> $1\n",
+		printf "<option value=\"$1\" %s>$1</option>\n",
 			$options{"proto"} eq $1 ? "selected" : "";
 		}
 	&close_tempfile(NETCONFIG);
@@ -719,11 +719,11 @@ if ($_[0] eq "nfs") {
 		    defined($options{"secure"}) ? "dh" :
 		    defined($options{"kerberos"}) ? "krb" : "";
 	print "<td><select name=nfs_auth>\n";
-	printf "<option value=\"\" %s> $text{'solaris_none'}\n",
+	printf "<option value=\"\" %s>$text{'solaris_none'}</option>\n",
 		$nfs_auth eq "" ? "selected" : "";
-	printf "<option value=dh %s> $text{'solaris_des'}\n",
+	printf "<option value=dh %s>$text{'solaris_des'}</option>\n",
 		$nfs_auth eq "dh" ? "selected" : "";
-	printf "<option value=krb %s> $text{'solaris_krb'}\n",
+	printf "<option value=krb %s>$text{'solaris_krb'}</option>\n",
 		$nfs_auth eq "krb" ? "selected" : "";
 	print "</select></td>\n";
 
@@ -769,7 +769,7 @@ if ($_[0] eq "ufs") {
 	print "<td><select name=ufs_onerror>\n";
 	foreach ('panic', 'lock', 'umount', 'repair') {
 		next if ($_ eq "repair" && $gconfig{'os_version'} >= 10);
-		printf "<option value=\"$_\" %s> $_\n",
+		printf "<option value=\"$_\" %s>$_</option>\n",
 		 $options{onerror} eq $_ ||
 		 !defined($options{onerror}) && $_ eq "panic" ? "selected" : "";
 		}
@@ -817,7 +817,7 @@ if ($_[0] eq "ufs") {
 		print "<td nowrap><input size=5 name=ufs_toosoon_time value='$1'>\n";
 		print "<select name=ufs_toosoon_units>\n";
 		foreach $u ('s', 'm', 'h', 'd', 'w', 'y') {
-			printf "<option value=%s %s> %s\n",
+			printf "<option value=%s %s>%s</option>\n",
 				$u, $2 eq $u ? "selected" : "", $text{"solaris_time_$u"};
 			}
 		print "</select></td> </tr>\n";
@@ -892,11 +892,11 @@ if ($_[0] eq "tmpfs") {
 	($tmpsz = $options{size}) =~ s/[A-z]+$//g;
 	print "<input name=tmpfs_size size=6 value=\"$tmpsz\">\n";
 	print "<select name=tmpfs_unit>\n";
-	printf "<option value=m %s> MB\n",
+	printf "<option value=m %s>MB</option>\n",
 		$options{"size"} =~ /m$/ ? "selected" : "";
-	printf "<option value=k %s> kB\n",
+	printf "<option value=k %s>kB</option>\n",
 		$options{"size"} =~ /k$/ ? "selected" : "";
-	printf "<option value=b %s> bytes\n",
+	printf "<option value=b %s>bytes</option>\n",
 		$options{"size"} !~ /(k|m)$/ ? "selected" : "";
 	print "</select></td>\n";
 
@@ -921,7 +921,7 @@ if ($_[0] eq "cachefs") {
 	if (!defined($options{backfstype})) { $options{backfstype} = "nfs"; }
 	foreach (&list_fstypes()) {
 		if ($_ eq "cachefs") { next; }
-		printf "<option value=\"$_\" %s>$_\n",
+		printf "<option value=\"$_\" %s>$_</option>\n",
 			$_ eq $options{backfstype} ? "selected" : "";
 		}
 	print "</select></td>\n";
@@ -946,10 +946,10 @@ if ($_[0] eq "cachefs") {
 
 	print "<tr> <td><b>$text{'solaris_con'}</b></td>\n";
 	print "<td><select name=cfs_con>\n";
-	print "<option value=1> $text{'solaris_period'}\n";
-	printf "<option value=0 %s> $text{'solaris_never'}\n",
+	print "<option value=1>$text{'solaris_period'}</option>\n";
+	printf "<option value=0 %s>$text{'solaris_never'}</option>\n",
 		defined($options{"noconst"}) ? "selected" : "";
-	printf "<option value=2 %s> $text{'solaris_demand'}\n",
+	printf "<option value=2 %s>$text{'solaris_demand'}</option>\n",
 		defined($options{"demandconst"}) ? "selected" : "";
 	print "</select></td>\n";
 
@@ -1075,11 +1075,11 @@ if ($_[0] eq "xmemfs") {
 	($tmpsz = $options{size}) =~ s/[A-z]+$//g;
 	print "<input name=xmemfs_size size=6 value=\"$tmpsz\">\n";
 	print "<select name=xmemfs_unit>\n";
-	printf "<option value=m %s> MB\n",
+	printf "<option value=m %s>MB</option>\n",
 		$options{"size"} =~ /m$/ ? "selected" : "";
-	printf "<option value=k %s> kB\n",
+	printf "<option value=k %s>kB</option>\n",
 		$options{"size"} =~ /k$/ ? "selected" : "";
-	printf "<option value=b %s> bytes\n",
+	printf "<option value=b %s>bytes</option>\n",
 		$options{"size"} !~ /(k|m)$/ ? "selected" : "";
 	print "</select></td>\n";
 
@@ -1098,7 +1098,8 @@ if ($_[0] eq "xmemfs") {
 sub check_location
 {
 if ($_[0] eq "nfs") {
-	local($out, $temp, $mout, $dirlist);
+	local($out, $temp, $mout, $dirlist, $qnfs_host, $qnfs_dir, $qtemp);
+	$qnfs_host = quotemeta($in{nfs_host});
 
 	if ($in{'nfs_serv'} == 1) {
 		# multiple servers listed.. assume the user has a brain
@@ -1116,7 +1117,7 @@ if ($_[0] eq "nfs") {
 	if ($in{nfs_host} !~ /^\S+$/) {
 		&error(&text('solaris_ehost', $in{'nfs_host'}));
 		}
-	$out = &backquote_command("dfshares '$in{nfs_host}' 2>&1");
+	$out = &backquote_command("dfshares $qnfs_host 2>&1");
 	if ($out =~ /Unknown host/) {
 		&error(&text('solaris_ehost2', $in{'nfs_host'}));
 		}
@@ -1137,7 +1138,9 @@ if ($_[0] eq "nfs") {
 		}
 	$temp = &transname();
 	&make_dir($temp, 0755);
-	$mout = &backquote_command("mount $in{nfs_host}:$in{nfs_dir} $temp 2>&1");
+	$qnfs_dir = quotemeta($in{nfs_dir});
+	$qtemp = quotemeta($temp);
+	$mout = &backquote_command("mount $qnfs_host:$qnfs_dir $qtemp 2>&1");
 	if ($mout =~ /No such file or directory/) {
 		rmdir($temp);
 		&error(&text('solaris_enfsdir', $in{'nfs_dir'},
@@ -1209,7 +1212,7 @@ elsif ($_[0] eq "swap") {
 		}
 	else { $dv = $in{swap_path}; }
 
-	if (!open(SWAPFILE, $dv)) {
+	if (!open(SWAPFILE, "<".$dv)) {
 		if ($! =~ /No such file/ && $in{swap_dev}) {
 			if ($dv !~ /^\/dev/) {
 				&swap_form($dv);
@@ -1330,7 +1333,7 @@ elsif ($_[0] =~ /^\/dev\/md\/dsk\/d(.)$/) {
 	}
 else {
 	# Some other device
-	if (!open(DEV, $_[0])) {
+	if (!open(DEV, "<".$_[0])) {
 		if ($! =~ /No such file or directory/) {
 			&error(&text('solaris_edevfile', $_[0]));
 			}
@@ -1645,8 +1648,10 @@ return @rv ? join(',' , @rv) : "-";
 # Attempt to create a swap file 
 sub create_swap
 {
-local($out);
-$out = &backquote_logged("mkfile $_[1]$_[2] $_[0] 2>&1");
+local($out, $qsize, $qfile);
+$qsize = quotemeta($_[1].$_[2]);
+$qfile = quotemeta($_[0]);
+$out = &backquote_logged("mkfile $qsize $qfile 2>&1");
 if ($?) {
 	&unlink_file($_[0]);
 	return "mkfile failed : $out";
